<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>DecoderSndFileFactory</name>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="63"/>
        <source>Sndfile Plugin</source>
        <translation>Módulo Sndfile</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="66"/>
        <source>PCM Files</source>
        <translation>Archivos PCM</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="130"/>
        <source>About Sndfile Audio Plugin</source>
        <translation>Acerca del módulo de sonido Sndfile</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="131"/>
        <source>Qmmp Sndfile Audio Plugin</source>
        <translation>Módulo de sonido Sndfile para Qmmp</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="132"/>
        <source>Compiled against</source>
        <translation>Compilado con</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="133"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
